"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import turbinia_api_lib
from turbinia_api_lib.model.base_request_options import BaseRequestOptions


class TestBaseRequestOptions(unittest.TestCase):
    """BaseRequestOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBaseRequestOptions(self):
        """Test BaseRequestOptions"""
        # FIXME: construct object with mandatory attributes with example values
        # model = BaseRequestOptions()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import turbinia_api_lib
from turbinia_api_lib.api.turbinia_tasks_api import TurbiniaTasksApi  # noqa: E501


class TestTurbiniaTasksApi(unittest.TestCase):
    """TurbiniaTasksApi unit test stubs"""

    def setUp(self):
        self.api = TurbiniaTasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_task_status(self):
        """Test case for get_task_status

        Get Task Status  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from turbinia_api_lib.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from turbinia_api_lib.model.base_request_options import BaseRequestOptions
from turbinia_api_lib.model.http_validation_error import HTTPValidationError
from turbinia_api_lib.model.request import Request
from turbinia_api_lib.model.validation_error import ValidationError
from turbinia_api_lib.model.validation_error_loc_inner import ValidationErrorLocInner



# flake8: noqa

"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from turbinia_api_lib.api_client import ApiClient

# import Configuration
from turbinia_api_lib.configuration import Configuration

# import exceptions
from turbinia_api_lib.exceptions import OpenApiException
from turbinia_api_lib.exceptions import ApiAttributeError
from turbinia_api_lib.exceptions import ApiTypeError
from turbinia_api_lib.exceptions import ApiValueError
from turbinia_api_lib.exceptions import ApiKeyError
from turbinia_api_lib.exceptions import ApiException



"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import turbinia_api_lib
from turbinia_api_lib.api.turbinia_requests_api import TurbiniaRequestsApi  # noqa: E501


class TestTurbiniaRequestsApi(unittest.TestCase):
    """TurbiniaRequestsApi unit test stubs"""

    def setUp(self):
        self.api = TurbiniaRequestsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_request(self):
        """Test case for create_request

        Create Request  # noqa: E501
        """
        pass

    def test_get_request_status(self):
        """Test case for get_request_status

        Get Request Status  # noqa: E501
        """
        pass

    def test_get_requests_summary(self):
        """Test case for get_requests_summary

        Get Requests Summary  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import turbinia_api_lib
from turbinia_api_lib.api.turbinia_configuration_api import TurbiniaConfigurationApi  # noqa: E501


class TestTurbiniaConfigurationApi(unittest.TestCase):
    """TurbiniaConfigurationApi unit test stubs"""

    def setUp(self):
        self.api = TurbiniaConfigurationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_evidence_attributes_by_name(self):
        """Test case for get_evidence_attributes_by_name

        Get Evidence Attributes By Name  # noqa: E501
        """
        pass

    def test_get_evidence_types(self):
        """Test case for get_evidence_types

        Get Evidence Types  # noqa: E501
        """
        pass

    def test_get_request_options(self):
        """Test case for get_request_options

        Get Request Options  # noqa: E501
        """
        pass

    def test_read_config(self):
        """Test case for read_config

        Read Config  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import turbinia_api_lib
from turbinia_api_lib.model.validation_error_loc_inner import ValidationErrorLocInner
globals()['ValidationErrorLocInner'] = ValidationErrorLocInner
from turbinia_api_lib.model.validation_error import ValidationError


class TestValidationError(unittest.TestCase):
    """ValidationError unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testValidationError(self):
        """Test ValidationError"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ValidationError()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import turbinia_api_lib
from turbinia_api_lib.model.base_request_options import BaseRequestOptions
globals()['BaseRequestOptions'] = BaseRequestOptions
from turbinia_api_lib.model.request import Request


class TestRequest(unittest.TestCase):
    """Request unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRequest(self):
        """Test Request"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Request()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from turbinia_api_lib.api.turbinia_configuration_api import TurbiniaConfigurationApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from turbinia_api_lib.api.turbinia_configuration_api import TurbiniaConfigurationApi
from turbinia_api_lib.api.turbinia_jobs_api import TurbiniaJobsApi
from turbinia_api_lib.api.turbinia_logs_api import TurbiniaLogsApi
from turbinia_api_lib.api.turbinia_request_results_api import TurbiniaRequestResultsApi
from turbinia_api_lib.api.turbinia_requests_api import TurbiniaRequestsApi
from turbinia_api_lib.api.turbinia_tasks_api import TurbiniaTasksApi
